pub enum CalibrationError {
ChannelSizeMismatch {
calsol_chans: usize,
data_chans: usize,
},
BadArrayShape {
argument: String,
function: String,
expected: String,
received: String,
},
}Expand description
Errors that can occur when calibrating visibilities.
Variants
ChannelSizeMismatch
When the number of channels in the calibration solution does not match the number of channels in the data.
Fields
BadArrayShape
Error for bad array shape in provided argument